# Contributing to Webmention Handler
We'd love to have your input. As such we've tried to make contributing to Webmention Handler as easy and straight forward as possible. Feel free to:

- Report a bug
- Discuss the current state of the code
- Submit a fix
- Propose a new feature
- Become a maintainer

## We Follow [Github Flow](https://docs.github.com/en/get-started/quickstart/github-flow)
As Such All Code Changes Happen Via Pull Requests. Pull requests are the best way to propose changes to the codebase. We actively welcome your pull requests:

1. Fork the repo and create your branch from `main`.
2. If you've added code that should be tested, add tests.
3. If you've changed APIs, update the documentation.
4. Ensure the test suite passes.
5. Make sure your commits and branch names follow [conventional commits](https://www.conventionalcommits.org/)
6. Issue that pull request!

## [Conventional Commits](https://www.conventionalcommits.org/) & Branch Naming
The Conventional Commits specification is a lightweight convention on top of commit messages. It provides an easy set of rules for creating an explicit commit history; which makes it easier to write automated tools on top of. This convention dovetails with SemVer, by describing the features, fixes, and breaking changes made in commit messages.
The commit message should be structured as follows:
```
<type>[optional scope]: <description>

[optional body]

[optional footer(s)]
```

Following on, Branch names should be structured as follows:
```
<type>---<description>
```

## Any contributions you make will be under the MIT Software License
When you submit code changes, your submissions are understood to be provided under the same [MIT License](https://github.com/vandie/webmention-handler-mongo/blob/main/LICENSE) that covers the project. Feel free to contact the maintainers if that's a concern.

## Report bugs using Github's [issues](https://github.com/vandie/webmention-handler-mongo/issues)
We use GitHub issues to track public bugs. Report a bug by [opening a new issue](https://github.com/vandie/webmention-handler-mongo/issues/new/choose); it's that easy!

## Bug reports should include detail and sample code
When writing bug reports, try to include as much **useful** information as you can to help us solve the problem quickly and effectively. In general, the following list is a good (but not exhaustive) list of what to include.

- A quick summary and/or background
- Steps to reproduce
  - Be specific.
  - Give sample code if you can.
- What you expected would happen
- What actually happens
- Notes - eg. Solutions that you've already tried, Error Logs, and test data

## License
By contributing, you agree that your contributions will be licensed under its [MIT License](https://github.com/vandie/webmention-handler-mongo/blob/main/LICENSE).

## Contributors (Made with [contrib.rocks](https://contrib.rocks))
<a href="https://github.com/vandie/webmention-handler-mongo/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=vandie/webmention-handler" />
</a>
