'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var mongodb = require('mongodb');

class MongoWebMentionStorage {
    constructor(config) {
        this.mongoClient = new mongodb.MongoClient(config.databaseUri);
        this.dbName = config.dbName;
        this.pendingCollection = config.pendingCollection;
        this.mentionCollection = config.mentionCollection;
        this.maxPendingFetch = config.maxPendingFetch || 50;
        this.limitMentionsPerPageFetch = config.limitMentionsPerPageFetch || 50;
    }
    db() {
        return this.mongoClient.db(this.dbName);
    }
    fetchCollection(collection) {
        const connection = this.db();
        return connection.collection(collection);
    }
    async addPendingMention(mention) {
        const collection = this.fetchCollection(this.pendingCollection);
        const result = await collection.updateOne(mention, { $set: { ...mention, processed: false } }, { upsert: true });
        return {
            _id: result.upsertedId,
            ...mention,
            processed: false
        };
    }
    async getNextPendingMentions() {
        const collection = this.fetchCollection(this.pendingCollection);
        const mentions = await collection.find({ processed: false }, { limit: this.maxPendingFetch }).toArray();
        const ids = mentions.map(({ _id }) => _id);
        await collection.updateMany({ _id: { $in: ids } }, { $set: { processed: true } });
        return mentions;
    }
    async deleteMention(mention) {
        const collection = this.fetchCollection(this.mentionCollection);
        await collection.deleteMany({ source: mention.source, target: mention.target });
        return null;
    }
    async storeMentionForPage(page, mention) {
        const collection = this.fetchCollection(this.mentionCollection);
        const storedMention = await collection.insertOne(mention);
        return { ...mention, _id: storedMention.insertedId };
    }
    async getMentionsForPage(page, type) {
        const q = {
            target: page
        };
        if (type)
            q.type = type;
        const collection = this.fetchCollection(this.mentionCollection);
        return collection.find(q, { limit: this.limitMentionsPerPageFetch }).toArray();
    }
}

exports.MongoWebMentionStorage = MongoWebMentionStorage;
//# sourceMappingURL=index.js.map
